@@ -28,7 +28,6 @@ def get_default_sphinx_config():
             "sphinx_copybutton",
             "myst_nb",
             "jupyter_book",
-            "sphinxcontrib.bibtex",
             "sphinx_thebe",
             "sphinx_comments",
             "sphinx.ext.intersphinx",
@@ -43,6 +42,7 @@ def get_default_sphinx_config():
         html_sourcelink_suffix="",
         numfig=True,
         panels_add_bootstrap_css=False,
+        suppress_warnings=["myst.domains"],
     )
 
 
@@ -255,15 +255,37 @@ def yaml_to_sphinx(yaml: dict):
     # Parse and Rendering
     parse = yaml.get("parse")
     if parse:
+        # Enable extra extensions
+        extensions = sphinx_config.get("myst_enable_extensions", [])
+        # TODO: deprecate this in v0.11.0
         if parse.get("myst_extended_syntax") is True:
-            sphinx_config["myst_dmath_enable"] = True
-            sphinx_config["myst_amsmath_enable"] = True
-            sphinx_config["myst_deflist_enable"] = True
-            sphinx_config["myst_admonition_enable"] = True
-            sphinx_config["myst_html_img_enable"] = True
-            sphinx_config["myst_figure_enable"] = True
-        if "myst_url_schemes" in parse:
-            sphinx_config["myst_url_schemes"] = parse.get("myst_url_schemes")
+            extensions.append(
+                [
+                    "colon_fence",
+                    "dollarmath",
+                    "amsmath",
+                    "deflist",
+                    "html_image",
+                ]
+            )
+            _message_box(
+                (
+                    "myst_extended_syntax is deprecated, instead specify extensions "
+                    "you wish to be enabled. See https://myst-parser.readthedocs.io/en/latest/using/syntax-optional.html"  # noqa: E501
+                ),
+                color="orange",
+                print_func=print,
+            )
+        for ext in parse.get("myst_enable_extensions", []):
+            if ext not in extensions:
+                extensions.append(ext)
+        if extensions:
+            sphinx_config["myst_enable_extensions"] = extensions
+
+        # Configuration values we'll just pass-through
+        for ikey in ["myst_substitutions", "myst_url_schemes"]:
+            if ikey in parse:
+                sphinx_config[ikey] = parse.get(ikey)
 
     # Execution
     execute = yaml.get("execute")
@@ -305,6 +327,7 @@ def yaml_to_sphinx(yaml: dict):
         sphinx_config["extensions"] = get_default_sphinx_config()["extensions"]
         if not isinstance(extra_extensions, list):
             extra_extensions = [extra_extensions]
+
         for extension in extra_extensions:
             if extension not in sphinx_config["extensions"]:
                 sphinx_config["extensions"].append(extension)
@@ -321,6 +344,15 @@ def yaml_to_sphinx(yaml: dict):
             if path not in sys.path:
                 add_paths.append(path)
 
+    # Citations
+    if yaml.get("bibtex_bibfiles"):
+        if "extensions" not in sphinx_config:
+            sphinx_config["extensions"] = get_default_sphinx_config()["extensions"]
+        if isinstance(yaml.get("bibtex_bibfiles"), str):
+            yaml["bibtex_bibfiles"] = [yaml["bibtex_bibfiles"]]
+        sphinx_config["bibtex_bibfiles"] = yaml["bibtex_bibfiles"]
+        sphinx_config["extensions"].append("sphinxcontrib.bibtex")
+
     # items in sphinx.config will override defaults,
     # rather than recursively updating them
     return sphinx_config, yaml.get("sphinx", {}).get("config") or {}, add_paths
